Learn R Programming

gofgamma (version 1.0)

gamma_est: Maximum-likelihood estimation of parameters for the gamma distribution

Description

The maximum-likelihood estimators for the shape and scale parameters of a gamma distribution are computed due to the method of Bhattacharya (2001).

Usage

gamma_est(data)

Arguments

data

vector of positive valued observations

Value

returns a bivariate vector containing (shape,scale) estimated parameter vector.

References

Bhattacharya, B. (2001) "Testing equality of scale parameters against restricted alternatives for \(m \ge 3\) gamma distributions with unknown common shape parameter". Journal of Statistical Computation and Simulations, 69(4):353-368, DOI

Examples

Run this code
# NOT RUN {
gamma_est(stats::rgamma(100,shape=3,scale=6))

# }

Run the code above in your browser using DataLab