Learn R Programming

gofgamma (version 1.0)

print.gofgamma: Print method for tests of Gamma distribution

Description

Printing objects of class "gofgamma".

Usage

# S3 method for gofgamma
print(x, ...)

Arguments

x

object of class "gofgamma".

...

further arguments to be passed to or from methods.

Value

the argument x, invisibly, as for all print methods.

Details

A gofgamma object is a named list of numbers and character string, supplemented with test (the name of the teststatistic). test is displayed as a title. The remaining elements are given in an aligned "name = value" format.

Examples

Run this code
# NOT RUN {
print(test.BE(rgamma(20,1)))
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab